@@ -57,8 +57,8 @@ class _NonLinearPerts():
         eta_max = 25 
 
         # inner and outer wake x position
-        x_box_outer =  lp.x_box
-        x_box_inner = -lp.x_box
+        x_box_outer =  lp.x_box_r
+        x_box_inner = -lp.x_box_l
 
         # find the index in the x grid corresponding to the edge of the box
         index_outer = np.argmin(np.abs(x - x_box_outer))
@@ -430,7 +430,7 @@ class _NonLinearPerts():
             self.linear_solution, 
             self.linear_t, 
             self.p.show_teta_debug_plots,
-            self.p.tf_fac
+            self.p.tf_fac,
         )
 
         timer_1 = time.perf_counter()
@@ -474,7 +474,8 @@ class _NonLinearPerts():
 
         # parameters of run
         Rp      = self.p.r_planet
-        x_match = 2*self.p.scale_box 
+        x_match_l = 2*self.p.scale_box_l
+        x_match_r = 2*self.p.scale_box_r
         l       = self.p.l
         cw      = -self.p.a_cw
         hr      = self.p.hr_planet
@@ -498,7 +499,7 @@ class _NonLinearPerts():
 
             [x_grid, y_grid] = np.meshgrid(x, y)
             r_grid = np.sqrt(x_grid**2 + y_grid**2)
-            pphi_grid = np.arctan2(y_grid, x_grid)
+            pphi_grid = np.arctan2(y_grid, x_grid) - self.p.phi_planet
 
             tt = _t_vector(r_grid, Rp, hr, q, p)
 
@@ -521,7 +522,8 @@ class _NonLinearPerts():
                 tf_outer,
                 tf_inner, 
                 Rp, 
-                x_match, 
+                x_match_l,
+                x_match_r,
                 l, 
                 cw, 
                 hr, 
@@ -539,13 +541,14 @@ class _NonLinearPerts():
                 csp, 
                 hr, 
                 q, 
-                p
+                p,
+                self.p.use_old_vel
             )
 
         # if using a cylindrical grid
         else:
             r = self.g.r
-            phi = self.g.phi
+            phi = self.g.phi - self.p.phi_planet
 
             r_grid, pphi_grid = np.meshgrid(r, phi)
 
@@ -570,7 +573,8 @@ class _NonLinearPerts():
                 tf_outer,
                 tf_inner, 
                 Rp, 
-                x_match, 
+                x_match_l,
+                x_match_r,
                 l, 
                 cw, 
                 hr, 
@@ -588,7 +592,8 @@ class _NonLinearPerts():
                 csp, 
                 hr, 
                 q, 
-                p
+                p,
+                self.p.use_old_vel
             )
         
         timer_1 = time.perf_counter()
@@ -596,4 +601,4 @@ class _NonLinearPerts():
 
         self.rho = dnl
         self.vr = 1e-5*unl
-        self.vphi = 1e-5*vnl
\ No newline at end of file
+        self.vphi = 1e-5*vnl
